@@ -40,7 +40,10 @@
 #' @export
 #' @import XML
 #' @import RCurl
-#' @import reshape2
+#' @import utils
+#' @import stats
+#' @importFrom  reshape2 melt
+#' @importFrom reshape2 dcast
 #' @examples
 #' siteNumber <- "02177000"
 #' startDate <- "2012-09-01"
@@ -403,8 +406,11 @@ importWaterML1 <- function(obs_url,asDateTime=FALSE, tz=""){
     qualColumns <- unique(qualColumns)
     
     sortingColumns <- names(mergedDF)[!(names(mergedDF) %in% c(dataColumns,qualColumns))]
-  
-    meltedmergedDF  <- melt(mergedDF,id.vars=sortingColumns)
+
+    meltedmergedDF <- reshape2::melt(mergedDF, measure.vars =  c(dataColumns,qualColumns),
+                            variable.name = "variable", value.name = "value", na.rm = FALSE)
+    rownames(meltedmergedDF) <- NULL
+    # meltedmergedDF  <- reshape2::melt(mergedDF,id.vars=sortingColumns)
     meltedmergedDF  <- meltedmergedDF[!is.na(meltedmergedDF$value),] 
     
     meltedmergedDF <- meltedmergedDF[!duplicated(meltedmergedDF),]
@@ -416,7 +422,7 @@ importWaterML1 <- function(obs_url,asDateTime=FALSE, tz=""){
     indexDups <- as.numeric(row.names(qualDups))
   
     if(length(indexDups) > 0){
-      mergedDF2 <- dcast(meltedmergedDF[-indexDups,], castFormula, drop=FALSE, value.var = "value",)
+      mergedDF2 <- reshape2::dcast(meltedmergedDF[-indexDups,], castFormula, drop=FALSE, value.var = "value")
       
       # Need to get value....
       dupInfo <- meltedmergedDF[indexDups, sortingColumns]
@@ -434,7 +440,7 @@ importWaterML1 <- function(obs_url,asDateTime=FALSE, tz=""){
       dataColumns2 <- !(names(mergedDF2) %in% sortingColumns)
       
     } else {
-      mergedDF2 <- dcast(meltedmergedDF, castFormula, drop=FALSE, value.var = "value")
+      mergedDF2 <- reshape2::dcast(meltedmergedDF, castFormula, drop=FALSE, value.var = "value")
       dataColumns2 <- !(names(mergedDF2) %in% sortingColumns)
     }
     
