@@ -31,18 +31,19 @@ test_that("General NWIS retrievals working", {
 
 test_that("General WQP retrievals working", {
   testthat::skip_on_cran()
+  # testthat::skip_on_cran()
   # Bring back when WQP is back
-#   nameToUse <- "pH"
-#   pHData <- readWQPdata(siteid="USGS-04024315",characteristicName=nameToUse)
-#   expect_is(pHData$ActivityStartDateTime, 'POSIXct')
-#   
-#   pHDataExpanded2 <- readWQPdata(bBox=c(-90.10,42.67,-88.64,43.35),
+  nameToUse <- "pH"
+  pHData <- readWQPdata(siteid="USGS-04024315",characteristicName=nameToUse)
+  expect_is(pHData$ActivityStartDateTime, 'POSIXct')
+  
+#   pHDataExpanded2 <- readWQPdata(bBox=c(-90.1,42.9,-89.9,43.1),
 #                                  characteristicName=nameToUse)
 #   expect_is(pHDataExpanded2$ActivityStartDateTime, 'POSIXct')
-#   
-#   startDate <- as.Date("2013-01-01")
-#   nutrientDaneCounty <- readWQPdata(countycode="US:55:025",startDate=startDate,
-#                          characteristicType="Nutrient")
-#   expect_is(nutrientDaneCounty$ActivityStartDateTime, 'POSIXct')
+  
+  startDate <- as.Date("2013-01-01")
+  nutrientDaneCounty <- readWQPdata(countycode="US:55:025",startDate=startDate,
+                         characteristicType="Nutrient")
+  expect_is(nutrientDaneCounty$ActivityStartDateTime, 'POSIXct')
    expect_that(1==1, is_true())                      
 })
